@@ -1,5 +1,5 @@
 package Text::Password::CoreCrypt;
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 use 5.8.8;
 use Moose;
@@ -44,7 +44,7 @@ No arguments are required. But you can set some parameters.
 
 =item default
 
-You can set default length with param 'default' like below
+You can set default length with param 'default' like below:
 
  $pwd = Text::Pasword::AutoMiglation->new( default => 12 );
 
@@ -52,9 +52,9 @@ You can set default length with param 'default' like below
 
 Or you can set default strength for password with param 'readablity'.
 
-It must be a Boolen, default is 1.
+It must be a boolean, default is 1.
 
-If it was set as 0, you can generate stronger passwords with generate()
+If it was set as 0, you can generate stronger passwords with generate().
 
  $pwd = Text::Pasword::AutoMiglation->new( readability => 0 );
 
@@ -64,7 +64,7 @@ If it was set as 0, you can generate stronger passwords with generate()
 
 =head3 verify( $raw, $hash )
 
-returns true if the verify is success
+returns true if the verification succeeds.
 
 =cut
 
@@ -81,9 +81,9 @@ sub verify {
 
 =head3 nonce($length)
 
-generates the strings with enough strength
+generates the strings with enough strength.
 
-the length defaults to 8($self->default)
+the length defaults to 8($self->default).
 
 =cut
 
@@ -103,9 +103,9 @@ sub nonce {
 
 =head3 encrypt($raw)
 
-returns hash with CORE::crypt()
+returns hash with CORE::crypt().
 
-salt will be made automatically
+salt will be made automatically.
 
 =cut
 
@@ -128,12 +128,12 @@ sub encrypt {
 
 =head3 generate($length)
 
-genarates pair of new password and it's hash
+genarates pair of new password and it's hash.
 
-not much readable characters(0Oo1Il|!2Zz5sS\$6b9qCcKkUuVvWwXx.,:;~\-^'"`) are fallen
+less readable characters(0Oo1Il|!2Zz5sS$6b9qCcKkUuVvWwXx.,:;~-^'"`) are forbidden
 unless $self->readability is 0.
 
-the length defaults to 8($self->default)
+the length defaults to 8($self->default).
 
 =cut
 
